@@ -31,7 +31,6 @@ dd_KI_ML = function(brtsM, brtsS, tsplit, initparsopt = c(0.5,0.1,2*(1 + length(
 #  . reltolf = relative tolerance of function value in optimization
 #  . abstolx = absolute tolerance of parameter values in optimization
 # - maxiter = the maximum number of iterations in the optimization
-
 options(warn=-1)
 brtsM = sort(abs(as.numeric(brtsM)),decreasing = TRUE)
 brtsS = sort(abs(as.numeric(brtsS)),decreasing = TRUE)
@@ -66,7 +65,7 @@ trparsfix = parsfix/(1 + parsfix)
 trparsfix[which(parsfix == Inf)] = 1
 pars2 = c(res,ddmodel,cond,tsplit,0,soc,tol,maxiter)
 initloglik = dd_KI_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,idparsnoshift = idparsnoshift,pars2 = pars2,brtsM = brtsM,brtsS = brtsS,missnumspec = missnumspec)
-cat("The likelihood for the initial parameter values is",initloglik,"\n")
+cat("The loglikelihood for the initial parameter values is",initloglik,"\n")
 if(initloglik == -Inf)
 {
    cat("The initial parameter values have a likelihood that is equal to 0 or below machine precision. Try again with different initial values.\n")
